<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:lxslt="http://xml.apache.org/xslt"
	xmlns:redirect="http://xml.apache.org/xalan/redirect"
    extension-element-prefixes="redirect">


<xsl:template match="IntegratedAnalysis" mode="scorecard-source-control">

    <xsl:variable name="packages-element" select="Packages"/>

    <html>
        <head>
            <link rel="stylesheet" type="text/css" href="stylesheet.css"/>
        </head>
        <body>

            <xsl:call-template name="page-header">
                <xsl:with-param name="main-menu-page-name" select="'scorecard'"/>
                <xsl:with-param name="page-name" select="'source-control'"/>
                <xsl:with-param name="dynamics-page-name" select="'source-control'"/>
                <xsl:with-param name="root-element" select="current()"/>
            </xsl:call-template>

            <h3>Source Control Metrics</h3>
            <p>
                The two top-most histograms below shows the number of change and error activity in the source control system that
                are related to each subsystem. Activity for one class is the number of different
                issues that class was modified in. When aggregating to package or subsystem, these numbers are summed; i.e. a package where three classes
                were modified, in 1, 4 and 2 issues respectively, will report 1 + 4 + 2 = 7 as the activity number. Note, however, that several modifications
                on a class in one issue, counts as one activity. Error activity is typically bugfixes, while change activity is any other changes (i.e.
                maintenance, new development, etc).
            </p>
            <p>
                The last two histograms below shows the number of classes that were changed in change issues and error issues
                respectively. Note that one class will be counted in both histograms, if it was modified in one or more change issues
                and one or more error issues.
            </p>
            <p>
                For each histogram column, you can roll over the diagrams to get details on which subsystem the column relates to.
                Click on it to go to a detailed view. On the bottom of the screen the data is presented in tabular form.
            </p>
            <br/>
            <table width="100%" class="details">
                <tr>
                    <td style="background-color: white;">
                        <div align="top">
                            <embed width="400" height="300" src="img/subsystem-total-activity-histogram.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
                        </div>
                    </td>
                    <td style="background-color: white;">
                        <div align="top">
                            <embed width="400" height="300" src="img/subsystem-error-percentage-histogram.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
                        </div>
                    </td>
                </tr>
                <tr>
                    <td style="background-color: white;">
                        <div align="top">
                            <embed width="400" height="300" src="img/subsystem-change-classes-histogram.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
                        </div>
                    </td>
                    <td style="background-color: white;">
                        <div align="top">
                            <embed width="400" height="300" src="img/subsystem-error-classes-histogram.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
                        </div>
                    </td>
                </tr>
            </table>
            <table width="100%" class="details">
                <xsl:call-template name="metric-header-source-control"/>

				<xsl:call-template name="subsystem-source-control-metrics">
					<xsl:with-param name="subsystem-name" select="'Total'"/>
					<xsl:with-param name="subsystem-link" select="'none'"/>
					<xsl:with-param name="change-activity" select="sum($packages-element/Package/Stats/source-control-metrics/change-activity)"/>
					<xsl:with-param name="error-activity" select="sum($packages-element/Package/Stats/source-control-metrics/error-activity)"/>
					<xsl:with-param name="change-classes" select="sum($packages-element/Package/Stats/source-control-metrics/change-classes)"/>
					<xsl:with-param name="error-classes" select="sum($packages-element/Package/Stats/source-control-metrics/error-classes)"/>
				</xsl:call-template>

				<xsl:for-each select="$radar-config-doc/radar-config/subsystems/subsystem">
					<xsl:variable name="subsystem-name" select="normalize-space(name)"/>
					<xsl:variable name="file-name"><xsl:call-template name="subsystem-url">
                    	<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
						<xsl:with-param name="anchor" select="'source-control-metrics'"/>
					</xsl:call-template></xsl:variable>
					<xsl:call-template name="subsystem-source-control-metrics">
						<xsl:with-param name="subsystem-name" select="$subsystem-name"/>
						<xsl:with-param name="subsystem-link" select="$file-name"/>
						<xsl:with-param name="change-activity" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/source-control-metrics/change-activity)"/>
						<xsl:with-param name="error-activity" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/source-control-metrics/error-activity)"/>
						<xsl:with-param name="change-classes" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/source-control-metrics/change-classes)"/>
						<xsl:with-param name="error-classes" select="sum($packages-element/Package[subsystem/@name = $subsystem-name]/Stats/source-control-metrics/error-classes)"/>
					</xsl:call-template>
				</xsl:for-each>
                <!--xsl:call-template name="metric-rows">
                    <xsl:with-param name="packages-element" select="$packages-element"/>
                    <xsl:with-param name="row-type" select="'source-control-metrics'"/>
                </xsl:call-template-->

            </table>
        </body>
    </html>


</xsl:template>


<xsl:template name="metric-header-source-control">
	<tr>
       <th>Source Control</th>
		<th>Total Activity</th>
		<th colspan="2">Change Activity</th>
		<th colspan="2">Error Activty</th>
		<th>Classes with Change Issues</th>
		<th>Classes with Error Issues</th>
    </tr>
</xsl:template>

<xsl:template name="subsystem-source-control-metrics">
    <xsl:param name="subsystem-name"/>
    <xsl:param name="subsystem-link"/>
    <xsl:param name="change-activity"/>
    <xsl:param name="error-activity"/>
    <xsl:param name="change-classes"/>
    <xsl:param name="error-classes"/>

    <xsl:variable name="activity" select="$change-activity + $error-activity"/>
    <xsl:variable name="change-percentage">
        <xsl:choose>
            <xsl:when test="$activity=0">0</xsl:when>
            <xsl:otherwise><xsl:value-of select="100 * $change-activity div $activity"/></xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="error-percentage">
        <xsl:choose>
            <xsl:when test="$activity=0">0</xsl:when>
            <xsl:otherwise><xsl:value-of select="100 * $error-activity div $activity"/></xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <tr>
     <td align="left">
         <xsl:choose>
             <xsl:when test="$subsystem-link != 'none'">
                <a href="{$subsystem-link}">
                   <xsl:value-of select="$subsystem-name"/>
                </a>
            </xsl:when>
            <xsl:otherwise>
                <b><xsl:value-of select="$subsystem-name"/></b>
            </xsl:otherwise>
        </xsl:choose>
     </td>
     <td align="right"><xsl:value-of select="$activity"/></td>
     <td align="right"><xsl:value-of select="$change-activity"/></td>
     <td align="right"><xsl:value-of select="format-number($change-percentage, '#.##')"/>%</td>
     <td align="right"><xsl:value-of select="$error-activity"/></td>
     <td align="right"><xsl:value-of select="format-number($error-percentage, '#.##')"/>%</td>
     <td align="right"><xsl:value-of select="$change-classes"/></td>
     <td align="right"><xsl:value-of select="$error-classes"/></td>
    </tr>
</xsl:template>



</xsl:stylesheet>
