<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:lxslt="http://xml.apache.org/xslt">

<xsl:template name="scorecard-table">
    <xsl:param name="system-quality-report"/>
    <table width="100%" class="scorecard" style="background-color: white; align: top;">
        <tr>
            <th colspan="3"><xsl:value-of select="$radar-config-doc/radar-config/defined-metrics/metric/@name"/>
                <br/>[<xsl:call-template name="print-formula">
                    <xsl:with-param name="metric" select="$radar-config-doc/radar-config/defined-metrics/metric"/>
                </xsl:call-template>]
            </th>
            <td style="background-color: white;" colspan="1"><br/></td>
            <xsl:call-template name="metric-value-cell">
                    <xsl:with-param name="value" select="$system-quality-report/metric/value"/>
            </xsl:call-template>
        </tr>


        <xsl:for-each select="$radar-config-doc/radar-config/defined-metrics/metric/metric">
            <xsl:variable name="abbreviation" select="@abbreviation"/>
            <tr>
                <td style="background-color: white;"><br/></td>
            </tr>
            <tr>
                <td style="background-color: white;"><br/></td>
                <th colspan="2">
                    <xsl:value-of select="@name"/>
                    <br/>[<xsl:call-template name="print-formula">
                    <xsl:with-param name="metric" select="current()"/>
                    </xsl:call-template>]
                </th>
                <td style="background-color: white;"><br/></td>
                <xsl:call-template name="metric-value-cell">
                    <xsl:with-param name="value" select="$system-quality-report/metric/metric[@abbreviation = $abbreviation]/value"/>
                </xsl:call-template>
            </tr>

            <xsl:for-each select="$system-quality-report/metric/metric[@abbreviation = $abbreviation]/metric">
                <tr><xsl:variable name="this-abbreviation" select="@abbreviation"/>
                    <td style="background-color: white;"><br/></td>
                    <td style="background-color: white;"><br/></td>
                    <th>
                        <xsl:value-of select="@name"/>
                        <br/>[<xsl:call-template name="print-formula">
                        <xsl:with-param name="metric" select="$radar-config-doc/radar-config/defined-metrics/metric/metric[@abbreviation = $abbreviation]/metric[@abbreviation = $this-abbreviation]"/>
                        </xsl:call-template>]
                    </th>
                    <td style="background-color: white;"><br/></td>
                    <xsl:call-template name="metric-value-cell">
                        <xsl:with-param name="value" select="value"/>
                    </xsl:call-template>
                </tr>
            </xsl:for-each>
        </xsl:for-each>
    </table>
</xsl:template>

<xsl:template name="print-formula">
    <xsl:param name="metric"/>
    <xsl:choose>
        <xsl:when test="$metric/@type = 'aggregate'">
            <xsl:value-of select="$metric/@abbreviation"/>=&#160;<xsl:for-each select="$metric/value/metric">
                    <xsl:value-of select="concat(@significance,'*',@abbreviation)"/>
                    <xsl:if test="position() != last()">&#160;+&#160;</xsl:if>
                </xsl:for-each>
        </xsl:when>
        <xsl:when test="$metric/@type = 'mean-count'">
            <xsl:value-of select="$metric/@abbreviation"/>=&#160;mean_count(<xsl:apply-templates select="$metric/value"/>)
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$metric/@abbreviation"/>=&#160;<xsl:apply-templates select="$metric/value"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="value">
    <xsl:for-each select="*">
        <xsl:choose>
            <xsl:when test="name() = 'stat'"><xsl:value-of select="@value"/></xsl:when>
            <xsl:when test="name() = 'lang'"><xsl:value-of select="@desc"/></xsl:when> 
            <xsl:when test="name() = 'number'"><xsl:value-of select="@value"/></xsl:when>
            <xsl:when test="name() = 'operator'">
                <xsl:choose>
                    <xsl:when test="@value = 'subtract'">&#160;-&#160;</xsl:when>
                    <xsl:when test="@value = 'add'">&#160;+&#160;</xsl:when>
                    <xsl:when test="@value = 'multiply'">*</xsl:when>
                    <xsl:when test="@value = 'divide'">&#247;</xsl:when>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="name() = 'value'">(<xsl:apply-templates select="current()"/>)</xsl:when>
            <xsl:when test="name() = 'packages'">total_packages</xsl:when>
            <xsl:when test="name() = 'count'">
                <xsl:choose>
                    <xsl:when test="@condition-value">count_packages(<xsl:value-of select="@value"/>=<xsl:value-of select="@condition-value"/>)</xsl:when>
                    <xsl:when test="@condition-not-value">count_packages(not(<xsl:value-of select="@value"/>=<xsl:value-of select="@condition-not-value"/>))</xsl:when>
                </xsl:choose>
            </xsl:when>
			<xsl:when test="name() = 'count-classes'">
				count_classes(<xsl:value-of select="@value"/>&lt;<xsl:value-of select="@max-value"/>)
			</xsl:when>
        </xsl:choose>
    </xsl:for-each>
</xsl:template>

<xsl:template name="metric-value-cell">
    <xsl:param name="value"/>
    <td align="center">
        <xsl:attribute name="style">background-color:<xsl:value-of select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@max-value &gt; $value]/@color"/></xsl:attribute>
        &#160;&#160;<xsl:value-of select="format-number($value,'#.##')"/>&#160;&#160;
    </td>
</xsl:template>

</xsl:stylesheet>
