<?xml version="1.0"  encoding="UTF-8"?>
<!--
    Inspired by Stylesheet written by Kurt Cagle  (Code from Professional XSL, Chapter 14, Wrox press, Spring 2001).
    See : http://www.zvon.org/HowTo/Output/howto_jj_svg_23.html
-->
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:template name="svgTextSplit">
          <xsl:param name="text"/>
          <xsl:param name="maxCharactersPerLine"/>
          <xsl:param name="lineDiff"/>
          <xsl:param name="style"/>
          <xsl:param name="x-pos"/>
          <xsl:param name="y-pos"/>

          <xsl:variable name="id" select="generate-id()"/>
          <text style="{$style}" id="{$id}" xmlns="http://www.w3.org/2000/svg">
               <xsl:call-template name="splitLines">
                    <xsl:with-param name="text" select="$text"/>
                    <xsl:with-param name="maxCharactersPerLine" select="$maxCharactersPerLine"/>
                    <xsl:with-param name="lineDiff" select="$lineDiff"/>
                    <xsl:with-param name="top-corner-x" select="$x-pos"/>
                    <xsl:with-param name="top-corner-y" select="$y-pos"/>
               </xsl:call-template>
          </text>
     </xsl:template>

     <xsl:template name="splitLines" xmlns="http://www.w3.org/2000/svg" >
          <xsl:param name="text"/>
          <xsl:param name="buffer" select=" '' "/>
          <xsl:param name="maxCharactersPerLine" select="40"/>
          <xsl:param name="lineDiff" select="40"/>
          <xsl:param name="lineNum" select="1"/>
          <xsl:param name="top-corner-x"/>
          <xsl:param name="top-corner-y"/>


         <xsl:variable name="currentText">
               <xsl:choose>
                    <xsl:when test="substring($text,string-length($text)) != ' '">
                         <xsl:value-of select="$text"/>
                         <xsl:text> </xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                         <xsl:value-of select="$text"/>
                    </xsl:otherwise>
               </xsl:choose>
          </xsl:variable>
          <xsl:variable name="next_word" select="substring-before($currentText,' ')"/>
          <xsl:variable name="textAfter" select="substring-after($currentText,' ')"/>
          <xsl:choose>
               <xsl:when test="$textAfter != ''">
                    <xsl:choose>
                         <xsl:when test="string-length(concat($buffer,' ',$next_word)) > $maxCharactersPerLine">
                              <tspan x="{$top-corner-x}" y="{$top-corner-y + $lineDiff * $lineNum}">
                                   <xsl:value-of select="$buffer"/>
                              </tspan>
                              <xsl:variable name="new_textAfter" select="concat($next_word,' ',$textAfter)"/>
                              <xsl:call-template name="splitLines">
                                   <xsl:with-param name="text" select="$new_textAfter"/>
                                   <xsl:with-param name="buffer" select="''"/>
                                   <xsl:with-param name="maxCharactersPerLine" select="$maxCharactersPerLine"/>
                                   <xsl:with-param name="lineDiff" select="$lineDiff"/>
                                   <xsl:with-param name="lineNum" select="$lineNum + 1"/>
                                   <xsl:with-param name="top-corner-x" select="$top-corner-x"/>
                                   <xsl:with-param name="top-corner-y" select="$top-corner-y"/>
                              </xsl:call-template>
                         </xsl:when>
                         <xsl:otherwise>
                              <xsl:variable name="new_buffer" select="concat($buffer,$next_word,' ')"/>
                              <xsl:call-template name="splitLines">
                                   <xsl:with-param name="text" select="$textAfter"/>
                                   <xsl:with-param name="buffer" select="$new_buffer"/>
                                   <xsl:with-param name="maxCharactersPerLine" select="$maxCharactersPerLine"/>
                                   <xsl:with-param name="lineDiff" select="$lineDiff"/>
                                   <xsl:with-param name="lineNum" select="$lineNum"/>
                                   <xsl:with-param name="top-corner-x" select="$top-corner-x"/>
                                   <xsl:with-param name="top-corner-y" select="$top-corner-y"/>
                              </xsl:call-template>
                         </xsl:otherwise>
                    </xsl:choose>
               </xsl:when>
               <xsl:otherwise>
                    <tspan x="{$top-corner-x}" y="{$top-corner-y + $lineDiff * $lineNum}">
                         <xsl:value-of select="concat($buffer,' ',$next_word)"/>
                    </tspan>
               </xsl:otherwise>
          </xsl:choose>
     </xsl:template>

</xsl:stylesheet>
